Method: Github::Client::Activity::Events#performed

Defined in:
lib/github_api/client/activity/events.rb

#performed(*args) ⇒ Object Also known as: user_performed, list_user_performed

List all events that a user has performed

If you are authenticated as the given user, you will see your private events. Otherwise, you’ll only see public events.

List all public events that a user has performed

Examples:

github = Github.new
github.activity.events.performed 'user-name'
github.activity.events.performed 'user-name' { |event| ... }
github = Github.new
github.activity.events.performed 'user-name', public: true
github.activity.events.performed 'user-name', public: true { |event| ... }

See Also:



186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/github_api/client/activity/events.rb', line 186

def performed(*args)
  arguments(args, required: [:user])
  params = arguments.params

  public_events = if params['public']
    params.delete('public')
    '/public'
  end

  response = get_request("/users/#{arguments.user}/events#{public_events}", params)
  return response unless block_given?
  response.each { |el| yield el }
end