Method: Github::Error::InvalidOptions#initialize

Defined in:
lib/github_api/error/client_error.rb

#initialize(invalid, valid) ⇒ InvalidOptions

Returns a new instance of InvalidOptions.



25
26
27
28
29
30
31
32
33
# File 'lib/github_api/error/client_error.rb', line 25

def initialize(invalid, valid)
  super(
    generate_message(
      problem: "Invalid option #{invalid.keys.join(', ')} provided for this request.",
      summary: "Github gem checks the request parameters passed to ensure that github api is not hit unnecessairly and to fail fast.",
      resolution: "Valid options are: #{valid.join(', ')}, make sure these are the ones you are using"
    )
  )
end