Method: Github::Client::Repos::Contents#update
- Defined in:
- lib/github_api/client/repos/contents.rb
#update(*args) ⇒ Object
Update a file
This method updates a file in a repository
Optional Parameters
The :author section is optional and is filled in with the :committer information if omitted. If the :committer information is omitted, the authenticated user’s information is used.
You must provide values for both :name and :email, whether you choose to use :author or :committer. Otherwise, you’ll receive a 500 status code.
Both the author and commiter parameters have the same keys:
175 176 177 |
# File 'lib/github_api/client/repos/contents.rb', line 175 def update(*args) create(*args) end |