Class: Github::GitData::Tags
Constant Summary collapse
- VALID_TAG_PARAM_NAMES =
This tags api only deals with tag objects - so only annotated tags, not lightweight tags.
%w[ tag message object type name email date sha url tagger ].freeze
- VALID_TAG_PARAM_VALUES =
{ 'type' => %w[ blob tree commit ] }
Constants included from Request
Request::METHODS, Request::METHODS_WITH_BODIES
Constants included from Connection
Constants included from Constants
Constants::ACCEPT, Constants::ACCEPTED_OAUTH_SCOPES, Constants::ACCEPT_CHARSET, Constants::CACHE_CONTROL, Constants::CONTENT_LENGTH, Constants::CONTENT_TYPE, Constants::DATE, Constants::ETAG, Constants::HEADER_LAST, Constants::HEADER_LINK, Constants::HEADER_NEXT, Constants::LOCATION, Constants::META_FIRST, Constants::META_LAST, Constants::META_NEXT, Constants::META_PREV, Constants::META_REL, Constants::OAUTH_SCOPES, Constants::PARAM_PAGE, Constants::PARAM_PER_PAGE, Constants::PARAM_START_PAGE, Constants::RATELIMIT_LIMIT, Constants::RATELIMIT_REMAINING, Constants::SERVER, Constants::USER_AGENT
Constants included from MimeType
Instance Attribute Summary
Attributes inherited from API
Attributes included from Authorization
Instance Method Summary collapse
-
#create(*args) ⇒ Object
Create a tag object Note that creating a tag object does not create the reference that makes a tag in Git.
-
#get(*args) ⇒ Object
(also: #find)
Get a tag.
Methods inherited from API
#api_methods_in, #append_arguments, #arguments, inherited, #initialize, #method_missing, #process_basic_auth, #set, #setup, #with, #yield_or_eval
Methods included from RateLimit
#ratelimit, #ratelimit_remaining
Methods included from Request
#delete_request, #get_request, #patch_request, #post_request, #put_request, #request
Methods included from Connection
#caching?, #clear_cache, #connection, #default_middleware, #default_options, #stack
Methods included from MimeType
Methods included from Authorization
#auth_code, #authenticated?, #authentication, #authorize_url, #basic_authed?, #client, #get_token
Constructor Details
This class inherits a constructor from Github::API
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Github::API
Instance Method Details
#create(*args) ⇒ Object
Create a tag object Note that creating a tag object does not create the reference that makes a tag in Git. If you want to create an annotated tag in Git, you have to do this call to create the tag object, and then create the refs/tags/[tag] reference. If you want to create a lightweight tag, you simply have to create the reference - this call would be unnecessary.
Parameters
-
:tag- String of the tag -
:message- String of the tag message -
:object- String of the SHA of the git object this is tagging -
:type- String of the type of the object we’re tagging. Normally this is acommitbut it can also be atreeor ablob - tagger.name
-
String of the name of the author of the tag
- tagger.email
-
String of the email of the author of the tag
- tagger.date
-
Timestamp of when this object was tagged
Examples
github = Github.new
github.git_data..create 'user-name', 'repo-name',
"tag" => "v0.0.1",
"message" => "initial version\n",
"type" => "commit",
"object" => "c3d0be41ecbe669545ee3e94d31ed9a4bc91ee3c",
"tagger" => {
"name" => "Scott Chacon",
"email" => "[email protected]",
"date" => "2011-06-17T14:53:3"
}
67 68 69 70 71 72 73 74 75 |
# File 'lib/github_api/git_data/tags.rb', line 67 def create(*args) arguments(args, :required => [:user, :repo]) do sift VALID_TAG_PARAM_NAMES assert_values VALID_TAG_PARAM_VALUES end params = arguments.params post_request("/repos/#{user}/#{repo}/git/tags", params) end |
#get(*args) ⇒ Object Also known as: find
Get a tag
Examples
github = Github.new
github.git_data..get 'user-name', 'repo-name', 'sha'
31 32 33 34 35 36 |
# File 'lib/github_api/git_data/tags.rb', line 31 def get(*args) arguments(args, :required => [:user, :repo, :sha]) params = arguments.params get_request("/repos/#{user}/#{repo}/git/tags/#{sha}", params) end |